==> breeze_website_builder_5.4.55.tar.gz: manage/wizard_complete.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created:	11/28/2013	ELL
// 

	include ("check_session.php");
	
	if ((BWB_BASE_DIR == '') && (BWB_WEBPAGE_DIR == ''))
		$website_file_path = "/index.php";
	elseif (BWB_BASE_DIR == '')
		$website_file_path = "/" . BWB_WEBPAGE_DIR . "/";
	elseif (BWB_WEBPAGE_DIR == '')
		$website_file_path = "/" . BWB_BASE_DIR . "/";
	else
		$website_file_path = "/" . BWB_BASE_DIR . "/" . BWB_WEBPAGE_DIR . "/";
?>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>Wizard Complete</title>
<link rel="stylesheet" href="manager.css" type="text/css">

<script language="javascript" type="text/javascript">
function OpenHelpWindow()
{
	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#main", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
}
</script>
</head>

<body>
<p>
	Congratulations!  You have built your website.  What do you want to do next? <br /><br /><br /><br />
    <table border="0" width="70%" align="center">
    <tr>
    <td>
     <div class='button_console_edit' style="width:200px;" onClick="parent.frames['workspace'].location='edit_page_select.php';"><span class='button_console_text_w_icon'>Edit Content</span></div>
    </td>
    <td>
    <div class='button_console_preview' style="width:200px;" onClick="window.open('<?php echo $website_file_path; ?>', 'MySite');"><span class='button_console_text_w_icon'>See Published Site</span></div>
    </td>
    </tr>
    </table>
    <br /><br /><br /><br /><br /><br /><br /><br /><br /><span class='small_message'>(Refresh the page after clicking 'See Published Site' to view correct styles.)</span>
</p>
</body>
</html>

==> breeze_website_builder_6.1.20.tar.gz: manage/wizard_complete.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created:	11/28/2013	ELL
// 

	include ("check_session.php");
	
	if ((BWB_BASE_DIR == '') && (BWB_WEBPAGE_DIR == ''))
		$website_file_path = "/index.php";
	elseif (BWB_BASE_DIR == '')
		$website_file_path = "/" . BWB_WEBPAGE_DIR . "/";
	elseif (BWB_WEBPAGE_DIR == '')
		$website_file_path = "/" . BWB_BASE_DIR . "/";
	else
		$website_file_path = "/" . BWB_BASE_DIR . "/" . BWB_WEBPAGE_DIR . "/";
?>

<!DOCTYPE html>
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>Wizard Complete | Breeze Website Builder</title>
<link rel="stylesheet" href="theme/<?php echo $theme; ?>/manager.css" type="text/css">

<style>
p, .small_message	{
	margin-left:100px;
	margin-right:100px;
}
</style>

<script language="javascript" type="text/javascript">
window.parent.document.title = document.title;

function OpenHelpWindow()
{
	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#main", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
}
</script>
</head>

<body>
<p>
	Congratulations!  You have built your website.  What do you want to do next? <br /><br /><br /><br />
    <table border="0" width="70%" align="center">
    <tr>
    <td>
     <div class='button_console_edit' style="width:200px;" onClick="window.location='/manage/main.php?module=edit_page_select.php&btn=btn_edit_content';"><span class='button_console_text_w_icon'>Edit Content</span></div>
    </td>
    <td>
    <div class='button_console_preview' style="width:200px;" onClick="window.open('<?php echo $website_file_path; ?>', 'MySite');"><span class='button_console_text_w_icon'>See Published Site</span></div>
    </td>
    </tr>
    </table>
    <br /><br /><br /><br /><br /><br /><br /><br /><br /><span class='small_message'>(Refresh the page after clicking 'See Published Site' to view correct styles.)</span>
</p>
</body>
</html>
